@@ -131,9 +131,15 @@ class MyStackedWidget(QtWidgets.QStackedWidget):
                 if ready:
                     break
                 time.sleep(0.2)
-            print('slot_',self.slot_no,'device ready')
-            self.cassettePolling=CassettePolling(self.slot_no, device[0], device[1], queueForResult, queueForCom, self.pollingCallback)
-            self.cassettePolling.start()
+            #print('slot_',self.slot_no,'device ready', ready, device)
+            if device[1] != INVALID_DEVICE_INDEX:
+                self.cassettePolling=CassettePolling(self.slot_no, device[0], device[1], queueForResult, queueForCom, self.pollingCallback)
+                self.cassettePolling.start()
+            else:
+                self.setCurrentIndex(SLOT_STATUS_WARNING)
+                page=self.currentWidget()
+                page.id.setText(self.tr('Camera fail'))
+                
             
         except Exception as error:
             print(error)
@@ -151,12 +157,9 @@ class MyStackedWidget(QtWidgets.QStackedWidget):
         try:
             #print("before setting widget index:",self.currentIndex(), status_index)
             if self.currentIndex() == SLOT_STATUS_EMPTY:
-                if status_index!= SLOT_STATUS_DETECTING and status_index!= SLOT_STATUS_SCAN:
+                if status_index!= SLOT_STATUS_DETECTING:
                     return
             
-            elif self.currentIndex() == SLOT_STATUS_SCAN:
-                if status_index!= SLOT_STATUS_DETECTING and status_index!= SLOT_STATUS_EMPTY:
-                    return
             self.cassetteId=cassette
             self.setCurrentIndex(status_index)
             #print("after  setting widget index:",self.currentIndex())
@@ -171,7 +174,8 @@ class MyStackedWidget(QtWidgets.QStackedWidget):
                 self.myTimer.stop()
         except Exception as e:
             print (e)
-
+    def setCassetteID(self,c_id):
+        self.cassetteId =c_id
     def detecting_(self, cassette):
         try:
             self.cassetteId=cassette
