@@ -103,7 +103,7 @@ class Target():
         if(height == calibration.FINAL_HEIGHT and width == calibration.FINAL_WIDTH): ## Return 1: For those pictures from server or dash board
             return NEGATIVE, image,
         
-        blc = self.balance(image,200)
+        blc = self.balance(image,198)
         x,y= self.firstBar(blc)
 #         print(x,y)
 #         cv2.imshow("blc", blc)
@@ -121,7 +121,8 @@ class Target():
 #             cv2.waitKey(0)
  
             cal = calibration.cr_modified(original_img, 0, 0)
-            return NEGATIVE, cal 
+            final = self.balance(cal,198)
+            return NEGATIVE, final 
         final = self.balance(cal,198)
 #         cv2.imshow("final", final)
 #         cv2.waitKey(0)
